@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2013 Emweb bvba, Leuven, Belgium.
+ * Copyright (C) 2013 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -31,9 +31,11 @@ public:
   virtual int numberOfCategories(Axis axis = Axis::X) const override;
   virtual WString categoryLabel(int u, Axis axis) const override;
   
-  virtual RenderRange computeRenderRange(Axis axis, 
-					 AxisScale scale = AxisScale::Linear)
+  virtual RenderRange computeRenderRange(
+      Axis axis, int yAxis, AxisScale scale = AxisScale::Linear)
     const override;
+
+  virtual bool onDemandLoadingEnabled() const override;
   
   virtual void update() override;
 
