@@ -6,27 +6,23 @@ auto container = Wt::cpp14::make_unique<Wt::WContainerWidget>();
 
 // Create four text widgets.
 Wt::WText *text1 =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WText>(
-                           "This text reacts to <tt>clicked()</tt>"));
+    container->addNew<Wt::WText>("This text reacts to <tt>clicked()</tt>");
 text1->setStyleClass("reactive");
 
 Wt::WText *text2 =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WText>(
-                           "This text reacts to <tt>doubleClicked()</tt>"));
+    container->addNew<Wt::WText>("This text reacts to <tt>doubleClicked()</tt>");
 text2->setStyleClass("reactive");
 
 Wt::WText *text3 =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WText>(
-                           "This text reacts to <tt>mouseWentOver()</tt>"));
+    container->addNew<Wt::WText>("This text reacts to <tt>mouseWentOver()</tt>");
 text3->setStyleClass("reactive");
 
 Wt::WText *text4 =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WText>(
-                           "This text reacts to <tt>mouseWentOut()</tt>"));
+    container->addNew<Wt::WText>("This text reacts to <tt>mouseWentOut()</tt>");
 text4->setStyleClass("reactive");
 
 // Create an additional text control to show status messages.
-Wt::WText *out = container->addWidget(Wt::cpp14::make_unique<Wt::WText>());
+Wt::WText *out = container->addNew<Wt::WText>();
 
 // Assign a signal/slot mechanism to the text controls.
 text1->clicked().connect([=] {
